from distutils.core import setup

setup(
	name = 'dill_list',
	version = '1.1.0',
	py_modules = ['dill_list'],
	author = 'd1ll1nger',
	author_email = 'hfpython@headfirstlabs.com',
	url = 'http://www.headfirstlabs.com',
	description = 'A simple printer of nested lists',
)



""" This is a function that performs recursive call on multi level arrays """

def print_lol(the_list,level):
	for each_item in the_list:
		if isinstance(each_item,list):
			print_lol(each_item,level+1)
		else:
			for each_indent in range(level):
				print("\t",end='')
			print(each_item)
